==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/MtlsEndpoints.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.MtlsSsoEndpoint;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * MtlsEndpoints
 */
@JsonPropertyOrder({ MtlsEndpoints.JSON_PROPERTY_SSO })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class MtlsEndpoints implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SSO = "sso";
    private MtlsSsoEndpoint sso;

    public MtlsEndpoints() {
    }

    public MtlsEndpoints sso(MtlsSsoEndpoint sso) {

        this.sso = sso;
        return this;
    }

    /**
     * Get sso
     *
     * @return sso
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SSO)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public MtlsSsoEndpoint getSso() {
        return sso;
    }

    @JsonProperty(JSON_PROPERTY_SSO)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSso(MtlsSsoEndpoint sso) {
        this.sso = sso;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        MtlsEndpoints mtlsEndpoints = (MtlsEndpoints) o;
        return Objects.equals(this.sso, mtlsEndpoints.sso);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(sso);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class MtlsEndpoints {\n");
        sb.append("    sso: ").append(toIndentedString(sso)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/MtlsEndpoints.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.MtlsSsoEndpoint;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * MtlsEndpoints
 */
@JsonPropertyOrder({ MtlsEndpoints.JSON_PROPERTY_SSO })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class MtlsEndpoints implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SSO = "sso";
    private MtlsSsoEndpoint sso;

    public MtlsEndpoints() {
    }

    public MtlsEndpoints sso(MtlsSsoEndpoint sso) {

        this.sso = sso;
        return this;
    }

    /**
     * Get sso
     *
     * @return sso
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SSO)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public MtlsSsoEndpoint getSso() {
        return sso;
    }

    @JsonProperty(JSON_PROPERTY_SSO)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSso(MtlsSsoEndpoint sso) {
        this.sso = sso;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        MtlsEndpoints mtlsEndpoints = (MtlsEndpoints) o;
        return Objects.equals(this.sso, mtlsEndpoints.sso);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(sso);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class MtlsEndpoints {\n");
        sb.append("    sso: ").append(toIndentedString(sso)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
